This repository is a library for creating th2-data-services applications.

## Installation
```
pip install th2-data-services
```
This package can be found on [PyPI](https://pypi.org/project/th2-data-services/ "th2-data-services").

## Docs
README and the templates are located [here](https://github.com/th2-net/th2-data-services-template).